/*
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License (the "License").
 * You may not use this file except in compliance with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 */

/*
 * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
 * Use is subject to license terms.
 *
 */

#pragma ident	"$Id: printer-query.c 146 2006-03-24 00:26:54Z njacobs $"

/*
 * This file contains a sample program that demonstrates how to query
 * a particular printer (print queue) from a print service.
 */

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <locale.h>
#include <libintl.h>
#include <alloca.h>
#include <papi.h>

static void
usage(char *program)
{
	char *name;

	if ((name = strrchr(program, '/')) == NULL)
		name = program;
	else
		name++;

	fprintf(stdout, gettext(
		"Usage: %s [-E] [-s service] [-o attribute] -d destination\n"),
		name);
	exit(1);
}


int
main(int ac, char *av[])
{
	papi_status_t status;
	papi_service_t svc = NULL;
	papi_encryption_t encryption = PAPI_ENCRYPT_NEVER;
	papi_printer_t printer = NULL;
	char **requested = NULL;
	char *service = NULL;
	char *destination = NULL;
	int c;

	(void) setlocale(LC_ALL, "");
	(void) textdomain("SUNW_OST_OSCMD");

	while ((c = getopt(ac, av, "d:Eo:s:")) != EOF)
		switch (c) {
		case 'd':	/* destination */
			destination = optarg;
			break;
		case 'E':	/* type */
			encryption = PAPI_ENCRYPT_ALWAYS;
			break;
		case 'o':	/* requested attribute */
			list_append(&requested, optarg);
			break;
		case 's':	/* type */
			service = optarg;
			break;
		default:
			usage(av[0]);
		}

	if (destination == NULL)
		usage(av[0]);

	/* create a connection to the print service */
	status = papiServiceCreate(&svc, service, NULL, NULL, NULL,
					encryption, NULL);
	if (status != PAPI_OK) {
		fprintf(stderr, gettext(
			"Failed to contact print service %s: %s\n"),
			(service ? service : "(default)"),
			papiStatusString(status));
		exit(1);
	}

	/* query the print service */
	status = papiPrinterQuery(svc, destination, requested, NULL, &printer);
	if (status != PAPI_OK) {
		fprintf(stderr, gettext("papiPrinterQuery(%s): %s\n"),
			destination, papiStatusString(status));
		exit(1);
	}

	if (printer != NULL) {
		papi_attribute_t **attributes =
				papiPrinterGetAttributeList(printer);
		char *prefix = "\n\t";
		char *buffer = NULL;
		ssize_t size = 0;

		while (papiAttributeListToString(attributes, prefix,
				buffer, size) != PAPI_OK) {
			size += 1024;
			buffer = alloca(size);
		}

		printf("%s at %s:%s%s\n", destination,
			(service ? service : "(default)"), prefix, buffer);
	}
	papiPrinterFree(printer);
	papiServiceDestroy(svc);

	exit(0);
}
