/*
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License (the "License").
 * You may not use this file except in compliance with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 */

/*
 * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
 * Use is subject to license terms.
 *
 */

#pragma ident	"$Id: remove-printer.c 146 2006-03-24 00:26:54Z njacobs $"

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <locale.h>
#include <libintl.h>
#include <fcntl.h>
#include <errno.h>
#include <papi.h>

static void
usage(char *program)
{
	char *name;

	if ((name = strrchr(program, '/')) == NULL)
		name = program;
	else
		name++;

	fprintf(stdout, gettext("Usage: %s (destination) ...\n"), name);
	exit(1);
}

void
remove_printer(char *destination)
{
	papi_status_t status;
	papi_service_t svc = NULL;
	papi_encryption_t encryption = PAPI_ENCRYPT_NEVER;

	status = papiServiceCreate(&svc, NULL, NULL, NULL, NULL,
					encryption, NULL);
	if (status != PAPI_OK) {
		fprintf(stderr, gettext(
			"Failed to contact service for %s: %s\n"), destination,
			papiStatusString(status));
	}

	status = papiPrinterRemove(svc, destination);
	if (status != PAPI_OK) {
		fprintf(stderr, gettext("jobPrinterRemove: %s: %s\n"),
			destination, papiStatusString(status));
	} else
		printf(gettext("removed: %s\n"), destination);

	papiServiceDestroy(svc);

	exit(0);
}

int
main(int ac, char *av[])
{
	int c;

	(void) setlocale(LC_ALL, "");
	(void) textdomain("SUNW_OST_OSCMD");

	for (c = 1; c < ac; c++)
		remove_printer(av[c]);

	return (0);
}
